<?php

namespace catchAdmin\hydraulic\model;

use catchAdmin\equipment\model\EquipmentType;
use catcher\base\CatchModel as Model;
use catchAdmin\permissions\model\DataRangScopeTrait;
use catchAdmin\permissions\model\Department as ModelDepartment;
use catchAdmin\system\model\SysDictData;
use Department;

class HydEquipment extends Model
{
    use DataRangScopeTrait;
    // 表名
    public $name = 'hydraulic_equipment';
    // 数据库字段映射
    public $field = array(
        'id',
        // 物料号
        'material_number',
        // 设备类别
        'equipment_type',
        // 工具名称
        'name',
        // 设备型号
        'equipment_model',
        // 发放单位
        'issue_unit',
        // 固定资产编号
        'fixed_asset_number',
        // 类固定资产编号
        'fixed_asset_number2',
        // 序列号
        'serial_number',
        // 出厂编号
        'factory_number',
        // 上次校验时间
        'check_last_time',
        // 下次校验时间
        'check_next_time',
        // 校验状态
        'check_status',
        // 状态
        'status',
        'longitude',
        'latitude',
        'address',

        // 创建人ID
        'creator_id',
        // 创建时间
        'created_at',
        // 更新时间
        'updated_at',
        // 软删除
        'deleted_at',
    );
    public function getList()
    {
        $res =  $this->dataRange()
            ->catchSearch()
            ->append(['classification', 'equ_type_name', 'list', 'status1', 'check_status1'])
            ->order($this->aliasField('id'), 'desc')
            ->paginate();
        return $res;
    }
    /**
     * 获取轨迹地图列表定位不分页 只查询有定位时间的
     */
    public function queryLocationList()
    {
        $res = $this->dataRange()
            ->catchSearch()

            ->select();
        return $res;
    }
    //物料号搜索
    public function searchMaterialNumberAttr($query, $value, $data)
    {

        return $query->where('material_number', 'like', '%' . $value . '%');
    }
    //设备类别搜索
    public function searchEquipmentTypeAttr($query, $value, $data)
    {
        return $query->where('equipment_type', '=', $value);
    }
    //名称
    public function searchNameAttr($query, $value, $data)
    {
        return $query->where('name', 'like', '%' . $value . '%');
    }
    //设备序列号以及设备资产编号
    public function searchNumberAttr($query, $value, $data)
    {

        return $query->where('serial_number|fixed_asset_number|fixed_asset_number2', 'like', '%' . $value . '%');
    }
    //根据pid 查询当前子类的设备
    public function searchPidAttr($query, $value, $data)
    {
        $eqtype = new  EquipmentType();
        $list = $eqtype->getIdbyPid($value);
        $ids = [];
        foreach ($list as $key => $value) {
            $ids[] = $value['id'];
        }
        return $query->where('equipment_type', 'in', $ids);
    }
    /**
     * @Descripttion: 搜索泵的Imei
     * @name: likang
     * @return {*}
     */
    public function searchImeiAttr($query, $value, $data)
    {
        $ids =  Hydraulic::where('imei', 'like', '%' . $value . '%')->column('eq_id');
        return $query->where('id', 'in', $ids);
    }


    public function getEquipmentTypeAttr()
    {
        $id = $this->getData('equipment_type');
        return intval($id);
    }
    public function getStatusAttr()
    {
        $id = $this->getData('status');
        return intval($id);
    }
    public function getCheckStatusAttr()
    {
        $id = $this->getData('check_status');
        return intval($id);
    }

    public function getClassificationAttr()
    {
        $id = $this->getData('equipment_type');
        $eq = new EquipmentType();
        $name = $eq->getParentNamebyChildId($id);
        return $name;
    }
    public function getEquTypeNameAttr()
    {
        $id = $this->getData('equipment_type');
        $name =  EquipmentType::where('id', $id)->value('name');
        return $name;
    }
    public function getCheckStatus1Attr()
    {
        $id = $this->getData('check_status');
        $Dict =  new SysDictData();
        $value = $Dict->getValueByCode('Check', $id);
        return $value;
    }
    public function getStatus1Attr()
    {
        $id = $this->getData('status');
        $Dict =  new SysDictData();

        $value = $Dict->getValueByCode('ToolStatus', $id);

        return $value;
    }
    // public function getCheckLastTimeAttr()
    // {
    //     $time = $this->getData('check_last_time');

    //     return $time ? date('Y-m-d', $time) : '';
    // }
    // public function getCheckNextTimeAttr()
    // {
    //     $time = $this->getData('check_next_time');
    //     return $time ? date('Y-m-d', $time) : '';
    // }
    public function getListAttr()
    {
        $id = $this->getData('id');
        $type_id = $this->getData('equipment_type');
        $sysdict = new SysDictData();
        $data = null;
        if ($type_id == 2) {
            $data = Hydraulic::where('eq_id', $id)->find();
            $data["department_name"] = ModelDepartment::where('id', $data['department_id'])->value('department_name');

            $data['alarm_state_name'] = $sysdict->getValueByCode('AlarmType', $data['alarm_state']);
            return  $data;
        }
        if ($type_id == 3 || $type_id == 4) {
            $data = Wrench::where('eq_id', $id)->find();
            $data["department_name"] = ModelDepartment::where('id', $data['department_id'])->value('department_name');
            $data['alarm_state_name'] = $sysdict->getValueByCode('AlarmType', $data['alarm_state']);
            return $data;
        } else {
            return null;
        }
    }



    /**
     * @Descripttion: 上传excel 信息
     * @name: likang
     * @return {*}
     */
    public function  importExcel()
    {
    }
    public function  exportExcel()
    {
    }
}
