<?php



use think\migration\Migrator;
use think\migration\db\Column;
use Phinx\Db\Adapter\MysqlAdapter;

class WorkPlan extends Migrator
{
    /**
     * Change Method.
     *
     * Write your reversible migrations using this method.
     *
     * More information on writing migrations is available here:
     * http://docs.phinx.org/en/latest/migrations.html#the-abstractmigration-class
     *
     * The following commands can be used in this method and Phinx will
     * automatically reverse them when rolling back:
     *
     *    createTable
     *    renameTable
     *    addColumn
     *    renameColumn
     *    addIndex
     *    addForeignKey
     *
     * Remember to call "create()" or "update()" and NOT "save()" when working
     * with the Table class.
     */
    public function change()
    {
        $table = $this->table('work_plan', ['engine' => 'InnoDB', 'collation' => 'utf8mb4_general_ci', 'comment' => '计划表', 'id' => 'id', 'signed' => true, 'primary_key' => ['id']]);
        $table->addColumn('wind_id', 'integer', ['limit' => MysqlAdapter::INT_REGULAR, 'null' => true, 'signed' => true, 'comment' => '风场id',])
            ->addColumn('fan_id', 'integer', ['limit' => MysqlAdapter::INT_REGULAR, 'null' => true, 'signed' => true, 'comment' => '风机id',])
            ->addColumn('work_sign', 'string', ['limit' => 12, 'null' => true, 'signed' => true, 'comment' => '工作位置',])
            ->addColumn('parts_sign', 'string', ['limit' => 12, 'null' => true, 'signed' => true, 'comment' => '部件类型',])
            ->addColumn('boit_type_sign', 'string', ['limit' => 12, 'null' => true, 'signed' => true, 'comment' => '螺栓型号',])
            ->addColumn('plan_name', 'string', ['limit' => 255, 'null' => true, 'signed' => true, 'comment' => '计划名称',])
            ->addColumn('plan_number', 'string', ['limit' => 50, 'null' => true, 'signed' => true, 'comment' => '计划编号',])
            ->addColumn('bolt_num', 'integer', ['limit' => MysqlAdapter::INT_REGULAR, 'null' => true, 'signed' => true, 'comment' => '螺栓总数',])
            ->addColumn('tighten_mode', 'integer', ['limit' => MysqlAdapter::INT_REGULAR, 'null' => true, 'signed' => true, 'comment' => '紧固模式',])
            ->addColumn('last_torque', 'string', ['limit' => 50, 'null' => true, 'signed' => true, 'comment' => '历史紧固扭矩',])
            ->addColumn('torque', 'string', ['limit' => 50, 'null' => true, 'signed' => true, 'comment' => '紧固扭矩',])
            ->addColumn('bias', 'string', ['limit' => 50, 'null' => true, 'signed' => true, 'comment' => '偏移禁锢数值',])
            ->addColumn('info', 'string', ['limit' => 255, 'null' => true, 'signed' => true, 'comment' => '详情',])
            ->addColumn('status', 'integer', ['limit' => MysqlAdapter::INT_REGULAR, 'null' => true, 'signed' => true, 'comment' => '状态  1 启用，-1 失效',])
            ->addColumn('creator_id', 'integer', ['limit' => MysqlAdapter::INT_REGULAR, 'null' => false, 'default' => 0, 'signed' => false, 'comment' => '创建人ID',])
            ->addColumn('created_at', 'integer', ['limit' => MysqlAdapter::INT_REGULAR, 'null' => false, 'default' => 0, 'signed' => false, 'comment' => '创建时间',])
            ->addColumn('updated_at', 'integer', ['limit' => MysqlAdapter::INT_REGULAR, 'null' => false, 'default' => 0, 'signed' => false, 'comment' => '更新时间',])
            ->addColumn('deleted_at', 'integer', ['limit' => MysqlAdapter::INT_REGULAR, 'null' => false, 'default' => 0, 'signed' => false, 'comment' => '软删除',])
            ->create();
    }
}
