<?php

namespace catchAdmin\worklocation\model;

use catchAdmin\api\Listen;
use catchAdmin\hydraulic\model\DeviceMold as ModelDeviceMold;
use catchAdmin\hydraulic\model\HydEquipment;
use catchAdmin\hydraulic\model\Wrench;
use catcher\base\CatchModel as Model;
use catchAdmin\permissions\model\DataRangScopeTrait;
use catchAdmin\wind\model\Fan;
use catchAdmin\wind\model\Wind;
use DeviceMold;
use think\facade\Db;

class WorkRecord extends Model
{

    use DataRangScopeTrait;
    // 表名
    public $name = 'work_record';
    // 数据库字段映射
    public $field = array(
        'id',
        // 风场编号
        'wind_number',
        // 风机编号
        'fan_number',
        //风机模型
        'fan_model',
        // 部件
        'parts',
        // 螺栓型号
        'boit_type',
        //工作位置
        'work_sign',
        // 螺栓编号
        'bolt_number',
        // 螺栓总数
        'boit_total',
        // 扳手编号
        'wrench_number',
        // 设定的扭矩1
        'set_torque',
        // 紧固扭矩1
        'fastening_torque',
        // 设定的压力
        'set_stress',
        // 紧固压力
        'fastening_stress',
        // 1 紧固正常，2紧固异常
        'fastening_status',
        // 紧固时间
        'fastening_time',
        // 搬动角度
        'move_angle',
        // 网关imei
        'imei',
        // 1 紧固模式，2维护模式
        'type',
        //1、普通扳手   2、角度扳手，未转角度    3、角度扳手，转动角度
        'wrench_type',
        // 创建人ID
        'creator_id',
        // 创建时间
        'created_at',
        // 更新时间
        'updated_at',
        // 软删除
        'deleted_at',
    );
    public function getList()
    {
        return $this->dataRange()
            ->catchSearch()
            ->append(['department_name', 'fan_model_name', 'wind_name', 'work_local_name', 'parts_name', 'boit_type_name', 'work_name', 'wrench_name'])
            ->field('*')
            ->catchOrder()
            ->creator()
            ->paginate();
    }
    /**
     * @Descripttion: 获取扳手的名称
     * @name: likang
     * @return {*}
     */
    public function getWrenchNameAttr()
    {
        $wrench =  $this->wrench_number;
        $eq_id =  Wrench::where('number', $wrench)->value('eq_id');
        $name = HydEquipment::where('id', $eq_id)->value('name');
        return $name;
    }
    public function getFanModelNameAttr()
    {

        return $this->fan_model;
    }
    //获取部门名称
    public function getDepartmentNameAttr()
    {
        $dep_id = Db::name('wind')->where('number', $this->wind_number)->value('department_id');
        $name = Db::name('departments')->where('id', $dep_id)->where('status', 1)->value('department_name');
        return $name;
    }

    /**
     * 获取风场名称
     *
     * @return void
     */
    public function getWindNameAttr()
    {
        $wind_number = $this->wind_number;
        $wind_name =  Db::name('wind')->where('number', $wind_number)->value('name');
        return $wind_name;
    }
    //获取操作人员
    public function getWorkNameAttr()
    {
        $user_id = $this->creator_id;
        $name =  Db::name("users")->where('id', $user_id)->value('realname');
        return $name;
    }
    //紧固模式
    public function getTypeAttr()
    {
        $type = $this->getData('type');
        if ($type == 1) {
            return '紧固模式';
        } else if ($type == 2) {
            return '维护模式';
        } else {
            return '未知模式';
        }
    }
    //时间
    public function getFasteningTimeAttr()
    {
        $time = $this->getData('fastening_time');
        return date('Y-m-d H:i:s', $time);
    }
    //扳手类型
    public function getWrenchTypeAttr()
    {
        $type = $this->getData('wrench_type');
        if ($type == 1) {
            return '普通扳手';
        } else if ($type == 2) {
            return '角度扳手，未转角度';
        } else if ($type == 3) {
            return '角度扳手，转动角度';
        } else {
            return '未知扳手';
        }
    }
    //紧固状态
    public function getFasteningStatusAttr()
    {
        $type = $this->getData('fastening_status');
        if ($type == 1) {
            return '紧固正常';
        } else if ($type == 2) {
            return '紧固异常';
        } else {
            return '未知状态';
        }
    }
    /**
     * 获取部件名称
     *
     * @return void
     */
    public function getPartsNameAttr()
    {
        $parts = $this->parts;
        return $parts;
    }
    //获取工作位置型号
    public function getWorkLocalNameAttr()
    {
        $code = $this->work_sign;

        return $code;
    }
    /**
     * 螺栓型号
     *
     * @return void
     */
    public function getBoitTypeNameAttr()
    {
        $code = $this->boit_type;
        return $code;
    }
    /**
     * 
     * @param [type] $type 类型
     * @param [type] $value 唯一value
     * @return void
     */
    public function get_dict_data($type, $value)
    {
        $where[] = ['device_type', "=", $type];
        $where[] = ['value', '=', $value];
        $name = Db::name('maintenance_mapper')->where($where)->value('name');
        return $name;
    }
}
