<?php

namespace catchAdmin\worklocation\model;

use catchAdmin\api\Listen;
use catchAdmin\hydraulic\model\DeviceMold;
use catchAdmin\hydraulic\model\MaintenanceMapper as ModelMaintenancemapper;
use catchAdmin\permissions\model\DataRangScopeTrait;
use catchAdmin\permissions\model\Users;
use catchAdmin\wind\model\Fan;
use catchAdmin\wind\model\Wind;
use catcher\base\CatchModel as Model;
use Maintenancemapper;

class Workplan extends Model
{
    use Listen;
    use DataRangScopeTrait;
    // 表名
    public $name = 'work_plan';
    // 数据库字段映射
    public $field = array(
        'id',
        // 风场id
        'plan_number',
        //计划编号
        'wind_id',
        // 风机id
        'fan_id',
        // 工作位置
        'work_sign',
        // 部件类型
        'parts_sign',
        // 螺栓型号
        'boit_type_sign',
        // 计划名称
        'plan_name',
        //螺栓总数
        'bolt_num',
        //紧固模式
        'tighten_mode',
        //偏移紧固数值
        'bias',
        //历史紧固扭矩
        'last_torque',
        //当前设定紧固扭矩
        'torque',
        // 详情
        'info',
        // 状态  1 启用，-1 失效
        'status',
        // 创建人ID
        'creator_id',
        // 创建时间
        'created_at',
        // 更新时间
        'updated_at',
        // 软删除
        'deleted_at',
    );
    /**
     * 监听转换
     */
    public function addContent(&$obj)
    {
        $data = null;
        $content = null;
        $fan = Fan::where('id', $obj->fan_id)->find();
        $fan_model = DeviceMold::where('id', $fan['fan_model'])->value('name');
        $wnum = Wind::where('id', $obj->wind_id)->value('number');
        $wname = Wind::where('id', $obj->wind_id)->value('name');
        $parts = ModelMaintenancemapper::where('device_type', 1)->where('value', $this->parts_sign)->value('name');
        $work = ModelMaintenancemapper::where('device_type', 2)->where('value', $this->work_sign)->value('name');
        $bm = ModelMaintenancemapper::where('device_type', 4)->where('value', $this->boit_type_sign)->value('name');
        $data = [
            'id' => $obj->id,
            'pnum' => $obj->plan_number,
            'wnum' => $wnum ? $wnum : '',
            'wname' => $wname ? $wname : '',
            'fnum' => $fan['number'],
            'fmodel' => $fan_model ? $fan_model : '',
            'parts' =>  $parts ? $parts : " ",
            'work' =>  $work ? $work : '',
            'bm' => $bm ? $bm : '',
            'bn' => intval($obj->bolt_num),
            'tm' => $obj->tighten_mode,
            'bias' => intval($obj->bias),
            'lt' => 0,
            'torque' => $obj->torque,
            'info' => $obj->info
        ];
        $content['data'] = $data;
        $content['type'] = 'WorkPlan';
        return  $content;
    }
    public function getList()
    {
        return $this->dataRange()
            ->catchSearch()
            ->append(['wind_name', 'fan_number', 'work_sign_name', 'parts_sign_name', 'boit_type_sign_name', 'status_name', 'creat_name', 'fan_model'])
            ->field('*')
            ->catchOrder()
            ->creator()
            ->paginate();
    }
    //获取风场名称
    public function getWindNameAttr()
    {
        $wind_id = $this->wind_id;
        $name =  Wind::where('id', $wind_id)->value('name');
        return $name;
    }
    //获取风机机位号
    public function getFanNumberAttr()
    {
        $fan_id = $this->fan_id;
        $number =  Fan::where('id', $fan_id)->value('number');
        return $number;
    }
    //获取工作位置
    public function getWorkSignNameAttr()
    {

        $name =  ModelMaintenancemapper::where('device_type', 2)->where('value', $this->work_sign)->value('name');
        return $name;
    }
    //获取部件
    public function getPartsSignNameAttr()
    {
        $name =  ModelMaintenancemapper::where('device_type', 1)->where('value', $this->parts_sign)->value('name');
        return $name;
    }
    //获取螺栓型号
    public function getBoitTypeSignNameAttr()
    {
        $name =  ModelMaintenancemapper::where('device_type', 4)->where('value', $this->boit_type_sign)->value('name');
        return $name;
    }
    public function getCreatNameAttr()
    {
        $name = null;
        $name =  Users::where('id', $this->creator_id)->value('realname');
        return $name;
    }
    //获取风机的型号id
    public function getFanModelAttr()
    {
        $fan_id = $this->fan_id;
        $fanModel =  Fan::where('id', $fan_id)->value('fan_model');
        return $fanModel;
    }
    public function searchPlanNameAttr($query, $value, $data)
    {
        return $query->where('plan_name', 'like', '%' . $value . '%');
    }
}
